Documentation
¶
Index ¶
- Constants
- func PromoteDraft(basePath string)
- type Attribution
- type Direction
- type Manager
- type Options
- type ProcessAttribution
- type Recorder
- func (r *Recorder) Close() error
- func (r *Recorder) CountConnectionOpened()
- func (r *Recorder) CountDNSQuery()
- func (r *Recorder) RecordPlatformEvent(eventType string)
- func (r *Recorder) Start() error
- func (r *Recorder) Touch(direction Direction, size int, by *Attribution)
- func (r *Recorder) UpdateNetworkType(networkType string)
Constants ¶
const ( DraftDirectoryName = "power_draft" ReportsDirectoryName = "power_reports" )
Variables ¶
This section is empty.
Functions ¶
func PromoteDraft ¶
func PromoteDraft(basePath string)
Types ¶
type Attribution ¶
type Attribution struct {
Inbound string `json:"inbound,omitempty"`
InboundType string `json:"inboundType,omitempty"`
Network string `json:"network,omitempty"`
Source string `json:"source,omitempty"`
Destination string `json:"destination,omitempty"`
Domain string `json:"domain,omitempty"`
Protocol string `json:"protocol,omitempty"`
User string `json:"user,omitempty"`
Process *ProcessAttribution `json:"process,omitempty"`
Rule string `json:"rule,omitempty"`
Chain []string `json:"chain,omitempty"`
Outbound string `json:"outbound,omitempty"`
OutboundType string `json:"outboundType,omitempty"`
Server string `json:"server,omitempty"`
DNS string `json:"dns,omitempty"`
DNSType string `json:"dnsType,omitempty"`
Endpoint string `json:"endpoint,omitempty"`
}
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
func NewManager ¶
func NewManager() *Manager
type ProcessAttribution ¶
type Recorder ¶
type Recorder struct {
// contains filtered or unexported fields
}
func NewRecorder ¶
func (*Recorder) CountConnectionOpened ¶
func (r *Recorder) CountConnectionOpened()
func (*Recorder) CountDNSQuery ¶
func (r *Recorder) CountDNSQuery()
func (*Recorder) RecordPlatformEvent ¶
func (*Recorder) Touch ¶
func (r *Recorder) Touch(direction Direction, size int, by *Attribution)
Touch reports one I/O activity: one read or write call, or one batched receive or send syscall on paths that batch packets. size is the size of the first packet of the activity and characterizes what ended an idle period; it is not accumulated. Volume totals come from the sampled interface counters instead.
func (*Recorder) UpdateNetworkType ¶
Click to show internal directories.
Click to hide internal directories.